@@ -12,7 +12,7 @@ that is the absence of authentication credential.
 
 It does not support any attributes.
 
-Copyright (C) 2011 CERN
+Copyright (C) 2012 CERN
 """
 
 from auth.credential import Credential
@@ -20,8 +20,4 @@ from auth.credential import Credential
 class Non(Credential):
     _keys = {'scheme' : {'match' : 'none'}}
     
-    def check(self):
-        """ Check the none credential object """
-        if self.__dict__ is None:
-            return True
     
\ No newline at end of file
